@@ -26,7 +26,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-plugin-manager.c 5402 2007-01-02 16:05:57Z paolo $
+ * $Id: gedit-plugin-manager.c 6079 2008-01-12 20:18:55Z sdeburca $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,7 +37,6 @@
 
 #include <glib/gi18n.h>
 #include <glade/glade-xml.h>
-#include <libgnome/gnome-url.h>
 
 #include "gedit-plugin-manager.h"
 #include "gedit-utils.h"
@@ -65,7 +64,7 @@ struct _GeditPluginManagerPrivate
 	GtkWidget	*about_button;
 	GtkWidget	*configure_button;
 
-	const GList	*plugins;
+	GeditPluginsEngine *engine;
 
 	GtkWidget 	*about;
 	
@@ -75,7 +74,7 @@ struct _GeditPluginManagerPrivate
 G_DEFINE_TYPE(GeditPluginManager, gedit_plugin_manager, GTK_TYPE_VBOX)
 
 static GeditPluginInfo *plugin_manager_get_selected_plugin (GeditPluginManager *pm); 
-static void plugin_manager_toggle_active (GtkTreeIter *iter, GtkTreeModel *model); 
+static void plugin_manager_toggle_active (GeditPluginManager *pm, GtkTreeIter *iter, GtkTreeModel *model);
 static void gedit_plugin_manager_finalize (GObject *object);
 
 static void 
@@ -105,12 +104,12 @@ about_button_cb (GtkWidget          *button,
 		gtk_widget_destroy (pm->priv->about);
 
 	pm->priv->about = g_object_new (GTK_TYPE_ABOUT_DIALOG,
-		"name", gedit_plugins_engine_get_plugin_name (info),
-		"copyright", gedit_plugins_engine_get_plugin_copyright (info),
-		"authors", gedit_plugins_engine_get_plugin_authors (info),
-		"comments", gedit_plugins_engine_get_plugin_description (info),
-		"website", gedit_plugins_engine_get_plugin_website (info),
-		"logo-icon-name", gedit_plugins_engine_get_plugin_icon_name (info),
+		"name", gedit_plugin_info_get_name (info),
+		"copyright", gedit_plugin_info_get_copyright (info),
+		"authors", gedit_plugin_info_get_authors (info),
+		"comments", gedit_plugin_info_get_description (info),
+		"website", gedit_plugin_info_get_website (info),
+		"logo-icon-name", gedit_plugin_info_get_icon_name (info),
 		NULL);
 
 	gtk_window_set_destroy_with_parent (GTK_WINDOW (pm->priv->about),
@@ -144,11 +143,12 @@ configure_button_cb (GtkWidget          *button,
 	g_return_if_fail (info != NULL);
 
 	gedit_debug_message (DEBUG_PLUGINS, "Configuring: %s\n", 
-			     gedit_plugins_engine_get_plugin_name (info));
+			     gedit_plugin_info_get_name (info));
 
 	toplevel = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET(pm)));
 
-	gedit_plugins_engine_configure_plugin (info, toplevel);
+	gedit_plugins_engine_configure_plugin (pm->priv->engine,
+					       info, toplevel);
 
 	gedit_debug_message (DEBUG_PLUGINS, "Done");	
 }
@@ -172,13 +172,11 @@ plugin_manager_view_info_cell_cb (GtkTreeViewColumn *tree_column,
 		return;
 
 	text = g_markup_printf_escaped ("<b>%s</b>\n%s",
-					gedit_plugins_engine_get_plugin_name (info),
-					gedit_plugins_engine_get_plugin_description (info));
+					gedit_plugin_info_get_name (info),
+					gedit_plugin_info_get_description (info));
 	g_object_set (G_OBJECT (cell),
-		      "markup",
-		      text,
-		      "sensitive",
-		      gedit_plugins_engine_plugin_is_available (info),
+		      "markup", text,
+		      "sensitive", gedit_plugin_info_is_available (info),
 		      NULL);
 
 	g_free (text);
@@ -202,10 +200,8 @@ plugin_manager_view_icon_cell_cb (GtkTreeViewColumn *tree_column,
 		return;
 
 	g_object_set (G_OBJECT (cell),
-		      "icon-name",
-		      gedit_plugins_engine_get_plugin_icon_name (info),
-		      "sensitive",
-		      gedit_plugins_engine_plugin_is_available (info),
+		      "icon-name", gedit_plugin_info_get_icon_name (info),
+		      "sensitive", gedit_plugin_info_is_available (info),
 		      NULL);
 }
 
@@ -229,7 +225,7 @@ active_toggled_cb (GtkCellRendererToggle *cell,
 	gtk_tree_model_get_iter (model, &iter, path);
 
 	if (&iter != NULL)
-		plugin_manager_toggle_active (&iter, model);
+		plugin_manager_toggle_active (pm, &iter, model);
 
 	gtk_tree_path_free (path);
 }
@@ -249,7 +245,7 @@ cursor_changed_cb (GtkTreeView *view,
 				  info != NULL);
 	gtk_widget_set_sensitive (GTK_WIDGET (pm->priv->configure_button),
 				  (info != NULL) && 
-				   gedit_plugins_engine_plugin_is_configurable (info));
+				   gedit_plugin_info_is_configurable (info));
 }
 
 static void
@@ -272,7 +268,7 @@ row_activated_cb (GtkTreeView       *tree_view,
 
 	g_return_if_fail (&iter != NULL);
 
-	plugin_manager_toggle_active (&iter, model);
+	plugin_manager_toggle_active (pm, &iter, model);
 }
 
 static void
@@ -284,7 +280,7 @@ plugin_manager_populate_lists (GeditPluginManager *pm)
 
 	gedit_debug (DEBUG_PLUGINS);
 
-	plugins = pm->priv->plugins;
+	plugins = gedit_plugins_engine_get_plugin_list (pm->priv->engine);
 
 	model = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (pm->priv->tree)));
 
@@ -295,8 +291,8 @@ plugin_manager_populate_lists (GeditPluginManager *pm)
 
 		gtk_list_store_append (model, &iter);
 		gtk_list_store_set (model, &iter,
-				    ACTIVE_COLUMN, gedit_plugins_engine_plugin_is_active (info),
-				    AVAILABLE_COLUMN, gedit_plugins_engine_plugin_is_available (info),
+				    ACTIVE_COLUMN, gedit_plugin_info_is_active (info),
+				    AVAILABLE_COLUMN, gedit_plugin_info_is_available (info),
 				    INFO_COLUMN, info,
 				    -1);
 
@@ -317,14 +313,15 @@ plugin_manager_populate_lists (GeditPluginManager *pm)
 				    INFO_COLUMN, &info, -1);
 
 		gtk_widget_set_sensitive (GTK_WIDGET (pm->priv->configure_button),
-					  gedit_plugins_engine_plugin_is_configurable (info));
+					  gedit_plugin_info_is_configurable (info));
 	}
 }
 
 static gboolean
-plugin_manager_set_active (GtkTreeIter  *iter,
-			   GtkTreeModel *model,
-			   gboolean      active)
+plugin_manager_set_active (GeditPluginManager *pm,
+			   GtkTreeIter        *iter,
+			   GtkTreeModel       *model,
+			   gboolean            active)
 {
 	GeditPluginInfo *info;
 	gboolean res = TRUE;
@@ -338,39 +335,31 @@ plugin_manager_set_active (GtkTreeIter  *iter,
 	if (active)
 	{
 		/* activate the plugin */
-		if (!gedit_plugins_engine_activate_plugin (info)) {
+		if (!gedit_plugins_engine_activate_plugin (pm->priv->engine, info)) {
 			gedit_debug_message (DEBUG_PLUGINS, "Could not activate %s.\n", 
-					     gedit_plugins_engine_get_plugin_name (info));
-					     
+					     gedit_plugin_info_get_name (info));
+
 			res = FALSE;
 		}
 	}
 	else
 	{
 		/* deactivate the plugin */
-		if (!gedit_plugins_engine_deactivate_plugin (info)) {
+		if (!gedit_plugins_engine_deactivate_plugin (pm->priv->engine, info)) {
 			gedit_debug_message (DEBUG_PLUGINS, "Could not deactivate %s.\n", 
-					     gedit_plugins_engine_get_plugin_name (info));
+					     gedit_plugin_info_get_name (info));
 
 			res = FALSE;
 		}
 	}
-  
-	/* set new value */
-	gtk_list_store_set (GTK_LIST_STORE (model), 
-			    iter, 
-			    ACTIVE_COLUMN,
-			    gedit_plugins_engine_plugin_is_active (info),
-			    AVAILABLE_COLUMN,
-			    gedit_plugins_engine_plugin_is_available (info),			    
-			    -1);
 
 	return res;
 }
 
 static void
-plugin_manager_toggle_active (GtkTreeIter  *iter,
-			      GtkTreeModel *model)
+plugin_manager_toggle_active (GeditPluginManager *pm,
+			      GtkTreeIter        *iter,
+			      GtkTreeModel       *model)
 {
 	gboolean active;
 	
@@ -380,7 +369,7 @@ plugin_manager_toggle_active (GtkTreeIter  *iter,
 
 	active ^= 1;
 
-	plugin_manager_set_active (iter, model, active);
+	plugin_manager_set_active (pm, iter, model, active);
 }
 
 static GeditPluginInfo *
@@ -423,7 +412,7 @@ plugin_manager_set_active_all (GeditPluginManager *pm,
 	gtk_tree_model_get_iter_first (model, &iter);
 
 	do {
-		plugin_manager_set_active (&iter, model, active);		
+		plugin_manager_set_active (pm, &iter, model, active);
 	}
 	while (gtk_tree_model_iter_next (model, &iter));
 }
@@ -448,7 +437,7 @@ name_search_cb (GtkTreeModel *model,
 	if (!info)
 		return FALSE;
 
-	normalized_string = g_utf8_normalize (gedit_plugins_engine_get_plugin_name (info), -1, G_NORMALIZE_ALL);
+	normalized_string = g_utf8_normalize (gedit_plugin_info_get_name (info), -1, G_NORMALIZE_ALL);
 	normalized_key = g_utf8_normalize (key, -1, G_NORMALIZE_ALL);
 	case_normalized_string = g_utf8_casefold (normalized_string, -1);
 	case_normalized_key = g_utf8_casefold (normalized_key, -1);
@@ -483,7 +472,7 @@ enable_plugin_menu_cb (GtkMenu            *menu,
 	g_return_if_fail (selection != NULL);
 
 	if (gtk_tree_selection_get_selected (selection, NULL, &iter))
-		plugin_manager_toggle_active (&iter, model);
+		plugin_manager_toggle_active (pm, &iter, model);
 }
 
 static void
@@ -526,18 +515,16 @@ create_tree_popup_menu (GeditPluginManager *pm)
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), image);
 	g_signal_connect (item, "activate",
 			  G_CALLBACK (configure_button_cb), pm);
-	gtk_widget_set_sensitive (item,
-				  gedit_plugins_engine_plugin_is_configurable (info));
+	gtk_widget_set_sensitive (item, gedit_plugin_info_is_configurable (info));
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
 	item = gtk_check_menu_item_new_with_mnemonic (_("A_ctivate"));
-	gtk_widget_set_sensitive (item,
-				  gedit_plugins_engine_plugin_is_available (info));	
+	gtk_widget_set_sensitive (item, gedit_plugin_info_is_available (info));
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item),
-					gedit_plugins_engine_plugin_is_active (info));
+					gedit_plugin_info_is_active (info));
 	g_signal_connect (item, "toggled",
 			  G_CALLBACK (enable_plugin_menu_cb), pm);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);					
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
 	item = gtk_separator_menu_item_new ();
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
@@ -646,8 +633,8 @@ model_name_sort_func (GtkTreeModel *model,
 	gtk_tree_model_get (model, iter1, INFO_COLUMN, &info1, -1);
 	gtk_tree_model_get (model, iter2, INFO_COLUMN, &info2, -1);
 
-	return g_utf8_collate (gedit_plugins_engine_get_plugin_name (info1),
-			       gedit_plugins_engine_get_plugin_name (info2));
+	return g_utf8_collate (gedit_plugin_info_get_name (info1),
+			       gedit_plugin_info_get_name (info2));
 }
 
 static void
@@ -659,7 +646,7 @@ plugin_manager_construct_tree (GeditPluginManager *pm)
 
 	gedit_debug (DEBUG_PLUGINS);
 
-	model = gtk_list_store_new (N_COLUMNS, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, G_TYPE_POINTER);
+	model = gtk_list_store_new (N_COLUMNS, G_TYPE_BOOLEAN, G_TYPE_BOOLEAN, GEDIT_TYPE_PLUGIN_INFO);
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (pm->priv->tree),
 				 GTK_TREE_MODEL (model));
@@ -746,6 +733,49 @@ plugin_manager_construct_tree (GeditPluginManager *pm)
 	gtk_widget_show (pm->priv->tree);
 }
 
+static void
+plugin_toggled_cb (GeditPluginsEngine *engine,
+		   GeditPluginInfo    *info,
+		   GeditPluginManager *pm)
+{
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	gboolean info_found = FALSE;
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (pm->priv->tree));
+
+	if (gtk_tree_selection_get_selected (selection, &model, &iter))
+	{
+		/* There is an item selected: it's probably the one we want! */
+		GeditPluginInfo *tinfo;
+		gtk_tree_model_get (model, &iter, INFO_COLUMN, &tinfo, -1);
+		info_found = info == tinfo;
+	}
+
+	if (!info_found)
+	{
+		gtk_tree_model_get_iter_first (model, &iter);
+
+		do
+		{
+			GeditPluginInfo *tinfo;
+			gtk_tree_model_get (model, &iter, INFO_COLUMN, &tinfo, -1);
+			info_found = info == tinfo;
+		}
+		while (!info_found && gtk_tree_model_iter_next (model, &iter));
+	}
+
+	if (!info_found)
+	{
+		g_warning ("GeditPluginManager: plugin '%s' not found in the tree model",
+			   gedit_plugin_info_get_name (info));
+		return;
+	}
+
+	gtk_list_store_set (GTK_LIST_STORE (model), &iter, ACTIVE_COLUMN, gedit_plugin_info_is_active (info), -1);
+}
+
 static void 
 gedit_plugin_manager_init (GeditPluginManager *pm)
 {
@@ -814,10 +844,19 @@ gedit_plugin_manager_init (GeditPluginManager *pm)
 
 	plugin_manager_construct_tree (pm);
 
-	/* get the list of available plugins (or installed) */
-	pm->priv->plugins = gedit_plugins_engine_get_plugins_list ();
+	/* get the plugin engine and populate the treeview */
+	pm->priv->engine = gedit_plugins_engine_get_default ();
 
-	if (pm->priv->plugins != NULL)
+	g_signal_connect_after (pm->priv->engine,
+				"activate-plugin",
+				G_CALLBACK (plugin_toggled_cb),
+				pm);
+	g_signal_connect_after (pm->priv->engine,
+				"deactivate-plugin",
+				G_CALLBACK (plugin_toggled_cb),
+				pm);
+
+	if (gedit_plugins_engine_get_plugin_list (pm->priv->engine) != NULL)
 	{
 		plugin_manager_populate_lists (pm);
 	}
@@ -833,6 +872,10 @@ gedit_plugin_manager_finalize (GObject *object)
 {
 	GeditPluginManager *pm = GEDIT_PLUGIN_MANAGER (object);
 
+	g_signal_handlers_disconnect_by_func (pm->priv->engine,
+					      plugin_toggled_cb,
+					      pm);
+
 	if (pm->priv->popup_menu)
 		gtk_widget_destroy (pm->priv->popup_menu);
 
